==> wp-tools-0.1.1.tgz: package/lib/cli.js <==
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../package.json');

var pkg = _interopRequireWildcard(_package);

var _commands = require('./commands');

var _commands2 = _interopRequireDefault(_commands);

var _config = require('./utils/config');

var _config2 = _interopRequireDefault(_config);

var _logger = require('./utils/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } } /**
                                                                                                                                                                                                     * External dependencies
                                                                                                                                                                                                     */


/**
 * Internal dependencies
 */


function main() {
	try {
		_commander2.default.version(pkg.version);
		setupCommands(_config2.default.read());
		runCommand();
	} catch (e) {
		_logger2.default.error(e.toString());
	}
}

function setupCommands(wptConfig) {
	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		var _loop = function _loop() {
			var k = _step.value;

			var v = _commands2.default[k];
			var cmd = _commander2.default.command(k);

			cmd.description(v.description);

			if ('undefined' !== typeof v.options) {
				v.options.forEach(function (opt) {
					cmd.option.apply(cmd, _toConsumableArray(opt));
				});
			}

			cmd.action(function (args) {
				v.action(args, wptConfig || {});
			});

			cmd.longDesc = longDescFn(k);
			cmd.helpInformation = helpInformation;
		};

		for (var _iterator = Object.keys(_commands2.default)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			_loop();
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator.return) {
				_iterator.return();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}
}

function runCommand() {
	var passedCmd = process.argv.slice(2);

	// No command specified or invalid command.
	if (!passedCmd.length || !_commands2.default[passedCmd[0]]) {
		_commander2.default.help();
	}

	_commander2.default.parse(process.argv);
}

function longDescFn(k) {
	var longDesc = _commands2.default[k].longDescription || '';

	return function () {
		return longDesc ? ['  ' + longDesc, ''] : [];
	};
}

function helpInformation() {
	var desc = this._description ? ['  ' + this._description, ''] : [];

	var name = this._alias ? this._name + '|' + this._alias : this._name;

	var usage = ['', '  Usage: ' + name + ' ' + this.usage(), ''];

	var cmdHelp = this.commandHelp();
	var cmds = cmdHelp ? [cmdHelp] : [];

	var options = ['  Options:', '', '' + this.optionHelp().replace(/^/gm, '    '), '', ''];

	return usage.concat(cmds).concat(desc).concat(this.longDesc()).concat(options).join('\n');
}

main();

==> wp-tools-0.3.0.tgz: package/lib/cli.js <==
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _package = require('../package.json');

var pkg = _interopRequireWildcard(_package);

var _commands = require('./commands');

var _commands2 = _interopRequireDefault(_commands);

var _config = require('./utils/config');

var _config2 = _interopRequireDefault(_config);

var _logger = require('./utils/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } } /**
                                                                                                                                                                                                     * External dependencies
                                                                                                                                                                                                     */


/**
 * Internal dependencies
 */


function main() {
	try {
		_commander2.default.version(pkg.version);
		setupCommands(_config2.default.read());
		runCommand();
	} catch (e) {
		_logger2.default.error(e.toString());
	}
}

function setupCommands(wptConfig) {
	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		var _loop = function _loop() {
			var k = _step.value;

			var v = _commands2.default[k];
			var cmd = _commander2.default.command(k);
			var options = v.options || [];

			cmd.description(v.description);

			options.forEach(function (opt) {
				cmd.option.apply(cmd, _toConsumableArray(opt));
			});

			if (v.arguments) {
				cmd.arguments(v.arguments);
			}

			cmd.action(function () {
				for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
					args[_key] = arguments[_key];
				}

				v.action.apply(v, args.concat([wptConfig || {}]));
			});

			cmd.longDesc = longDescFn(k);
			cmd.helpInformation = helpInformation;
		};

		for (var _iterator = Object.keys(_commands2.default)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			_loop();
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator.return) {
				_iterator.return();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}
}

function runCommand() {
	var passedCmd = process.argv.slice(2);

	// No command specified or invalid command.
	if (!passedCmd.length || !_commands2.default[passedCmd[0]]) {
		_commander2.default.help();
	}

	_commander2.default.parse(process.argv);
}

function longDescFn(k) {
	var longDesc = _commands2.default[k].longDescription || '';

	return function () {
		return longDesc ? ['  ' + longDesc, ''] : [];
	};
}

function helpInformation() {
	var desc = this._description ? ['  ' + this._description, ''] : [];

	var name = this._alias ? this._name + '|' + this._alias : this._name;

	var usage = ['', '  Usage: ' + name + ' ' + this.usage(), ''];

	var cmdHelp = this.commandHelp();
	var cmds = cmdHelp ? [cmdHelp] : [];

	var options = ['  Options:', '', '' + this.optionHelp().replace(/^/gm, '    '), '', ''];

	return usage.concat(cmds).concat(desc).concat(this.longDesc()).concat(options).join('\n');
}

main();
